@@ -1,68 +1,24 @@
-=head1 NAME
-
-XML::Atom::Microformats - parse microformats in Atom content
-
-=head1 SYNOPSIS
-
- use XML::Atom::Microformats;
- 
- my $feed = HTML::Microformats
-             ->new_feed($xml, $base_uri)
-             ->assume_profile(qw(hCard hCalendar));
- print $feed->json(pretty => 1);
- 
- use RDF::TrineShortcuts qw(rdf_query);
- my $results = rdf_query($sparql, $feed->model);
- 
-=cut
-
 package XML::Atom::Microformats;
 
+use 5.010;
+use autodie;
 use common::sense;
-use 5.008;
+use utf8;
 
-use HTML::Microformats 0.100;
-use JSON;
-use RDF::Query;
-use XML::Atom::OWL 0.100;
+use HTML::Microformats 0.100 qw();
+use JSON 2.00 qw();
+use RDF::Trine 0.135 qw();
+use RDF::Query 2.900 qw();
+use XML::Atom::OWL 0.100 qw();
 
-our $VERSION = '0.001';
-our $HAS_RDFA;
-
-BEGIN
-{
-	eval "use RDF::RDFa::Parser; use RDF::RDFa::Parser::Config;";
-	$HAS_RDFA = $@ ? 0 : 1 ;
+our ($VERSION, $AUTHORITY, $HAS_RDFA);
+BEGIN {
+	$XML::Atom::Microformats::VERSION   = '0.003';
+	$XML::Atom::Microformats::AUTHORITY = 'cpan:TOBYINK';
+	$XML::Atom::Microformats::HAS_RDFA  =
+		eval "use RDF::RDFa::Parser 1.096; 1;" || 0;
 }
 
-=head1 DESCRIPTION
-
-The XML::Atom::Microformats module brings the functionality of
-L<HTML::Microformats> to Atom 1.0 Syndication feeds. It finds
-microformats embedded in the E<lt>contentE<gt> elements
-(note: not E<lt>summaryE<gt>) of Atom entries.
-
-The general pattern of usage is to create an XML::Atom::Microformats
-object (which corresponds to an Atom 1.0 feed) using the
-C<new_feed> method; then ask for the data, as a Perl hashref,
-a JSON string, or an RDF::Trine model.
-
-=head2 Constructor
-
-=over 4
-
-=item C<< $feed = XML::Atom::Microformats->new_feed($xml, $base_url) >>
-
-Constructs a feed object.
-
-$xml is the Atom source (string) or an XML::LibXML::Document.
-
-$base_url is the feed URL, important for resolving relative URL references.
-
-=back
-
-=cut
-
 sub new_feed
 {
 	my ($class, $xml, $base_uri) = @_;
@@ -71,7 +27,11 @@ sub new_feed
 
 	if ($HAS_RDFA)
 	{
-		my $cfg = RDF::RDFa::Parser::Config->new('atom', '1.0', atom_parser=>1);
+		my $cfg = RDF::RDFa::Parser::Config->new(
+			RDF::RDFa::Parser::Config->HOST_ATOM,
+			RDF::RDFa::Parser::Config->RDFA_11,
+			atom_parser => 1,
+			);
 		$awol = RDF::RDFa::Parser->new($xml, $base_uri, $cfg, RDF::Trine::Store::Memory->temporary_store)->consume;
 	}
 	else
@@ -174,44 +134,6 @@ sub _prepare_contexts
 	return $self;
 }
 
-=head2 Profile Management
-
-HTML::Microformats uses HTML profiles (i.e. the profile attribute on the
-HTML <head> element) to detect which Microformats are used on a page. Any
-microformats which do not have a profile URI declared will not be parsed.
-
-XML::Atom::Microformats uses a similar mechanism. Because Atom does not
-have a E<lt>headE<gt> element, Atom E<lt>linkE<gt> is used instead:
-
-  <link rel="profile" href="http://ufs.cc/x/hcalendar" />
-
-These links can be used on a per-entry basis, or for the whole feed.
-
-Because many feeds fail to properly declare which profiles they use, there
-are various profile management methods to tell XML::Atom::Microformats to
-assume the presence of particular profile URIs, even if they're actually
-missing.
-
-=over 4
-
-=item C<< $feed->add_profile(@profiles) >>,
-C<< $feed->entry_add_profile($entryid, @profiles) >>
-
-Using C<add_profile> you can add one or more profile URIs, and they are
-treated as if they were found on the document.
-
-For example:
-
- $feed->add_profile('http://microformats.org/profile/rel-tag')
-
-This is useful for adding profile URIs declared outside the document itself
-(e.g. in HTTP headers).
-
-C<entry_add_profile> is a variant to allow you to add a profile which applies
-only to one specific entry within the feed, if you know that entry's ID.
-
-=cut
-
 sub add_profile
 {
 	my ($self, @profiles) = @_;
@@ -235,22 +157,6 @@ sub entry_add_profile
 	return $self;
 }
 
-=item C<< $feed->assume_profile(@microformats) >>,
-C<< $feed->entry_assume_profile($entryid, @profiles) >>
-
-For example:
-
- $feed->assume_profile(qw(hCard adr geo))
-
-This method acts similarly to C<add_profile> but allows you to use
-names of microformats rather than URIs. Microformat names are case
-sensitive, and must match HTML::Microformats::Format::Foo module names.
-
-C<entry_assume_profile> is a variant to allow you to add a profile which applies
-only to one specific entry within the feed, if you know that entry's ID.
-
-=cut
-
 sub assume_profile
 {
 	my ($self, @profiles) = @_;
@@ -274,16 +180,6 @@ sub entry_assume_profile
 	return $self;
 }
 
-=item C<< $feed->assume_all_profiles >>,
-C<< $feed->entry_assume_all_profiles($entryid) >>
-
-This method is equivalent to calling C<assume_profile> for
-all known microformats.
-
-=back
-
-=cut
-
 sub assume_all_profiles
 {
 	my ($self) = @_;
@@ -307,24 +203,9 @@ sub entry_assume_all_profiles
 	return $self;
 }
 
-=head2 Parsing Microformats
-
-Generally speaking, you can skip this. The C<data>, C<json> and
-C<model> methods will automatically do this for you.
-
-=over 4
-
-=item C<< $feed->parse_microformats >>
-
-Scans through the feed, finding microformat objects.
-
-On subsequent calls, does nothing (as everything is already parsed).
-
-=cut
-
 sub parse_microformats
 {
-	my $self = shift;
+	my ($self) = @_;
 	return $self if $self->{'parsed'};
 	
 	foreach my $context (@{$self->{'contexts'}})
@@ -337,19 +218,10 @@ sub parse_microformats
 	return $self;
 }
 
-=item C<< $feed->clear_microformats >>
-
-Forgets information gleaned by C<parse_microformats> and thus allows
-C<parse_microformats> to be run again. This is useful if you've modified
-added some profiles between runs of C<parse_microformats>.
-
-=back
-
-=cut
 
 sub clear_microformats
 {
-	my $self = shift;
+	my ($self) = @_;
 	
 	foreach my $context (@{$self->{'contexts'}})
 	{
@@ -362,30 +234,6 @@ sub clear_microformats
 	return $self;
 }
 
-=head2 Retrieving Data
-
-These methods allow you to retrieve the feed's data, and do things
-with it.
-
-=over 4
-
-=item C<< $feed->objects($format) >>,
-C<< $feed->entry_objects($entryid, $format) >>
-
-$format is, for example, 'hCard', 'adr' or 'RelTag'.
-
-Returns a list of objects of that type. (If called in scalar context,
-returns an arrayref.)
-
-Each object is, for example, an HTML::Microformat::hCard object, or an
-HTML::Microformat::RelTag object, etc. See the relevent documentation
-for details.
-
-C<entry_objects> is a variant to allow you to fetch data for
-one specific entry within the feed, if you know that entry's ID.
-
-=cut
-
 sub objects
 {
 	my ($self, $format, $entry) = @_;
@@ -414,21 +262,6 @@ sub entry_objects
 	return $self->objects($format, $entry);
 }
 
-=item C<< $feed->all_objects >>,
-C<< $feed->entry_all_objects($entryid) >>
-
-Returns a hashref of data. Each hashref key is the name of a microformat
-(e.g. 'hCard', 'RelTag', etc), and the values are arrayrefs of objects.
-
-Each object is, for example, an HTML::Microformat::hCard object, or an
-HTML::Microformat::RelTag object, etc. See the relevent documentation
-for details.
-
-C<entry_all_objects> is a variant to allow you to fetch data for
-one specific entry within the feed, if you know that entry's ID.
-
-=cut
-
 sub all_objects
 {
 	my ($self, $entry) = @_;
@@ -449,23 +282,6 @@ sub TO_JSON
 	return  $_[0]->all_objects;
 }
 
-=item C<< $feed->json(%opts) >>,
-C<< $feed->entry_json($entryid, %opts) >>
-
-Returns data roughly equivalent to the C<all_objects> method, but as a JSON
-string.
-
-%opts is a hash of options, suitable for passing to the L<JSON>
-module's to_json function. The 'convert_blessed' and 'utf8' options are
-enabled by default, but can be disabled by explicitly setting them to 0, e.g.
-
-  print $feed->json( pretty=>1, canonical=>1, utf8=>0 );
-
-C<entry_json> is a variant to allow you to fetch data for
-one specific entry within the feed, if you know that entry's ID.
-
-=cut
-
 sub json
 {
 	my ($self, %opts) = @_;
@@ -476,7 +292,7 @@ sub json
 	$opts{'utf8'} = 1
 		unless defined $opts{'utf8'};
 
-	return to_json($self->all_objects, \%opts);
+	return JSON::to_json($self->all_objects, \%opts);
 }
 
 sub entry_json
@@ -489,32 +305,9 @@ sub entry_json
 	$opts{'utf8'} = 1
 		unless defined $opts{'utf8'};
 
-	return to_json($self->entry_all_objects($entry), \%opts);
+	return JSON::to_json($self->entry_all_objects($entry), \%opts);
 }
 
-=item C<< $feed->model(%opts) >>,
-C<< $feed->entry_model($entryid, %opts) >>
-
-Returns data as an RDF::Trine::Model, suitable for serialising as
-RDF or running SPARQL queries. Quads are used (rather than
-triples) which allows you to trace statements to the entries from
-which they came.
-
-C<entry_model> is a variant to allow you to fetch data for
-one specific entry within the feed, if you know that entry's ID.
-
-$opts{'atomowl'} is a boolean indicating whether or not to
-include data from XML::Atom::OWL in the returned model.
-If enabled, this always includes AtomOWL data for the whole
-feed (not just for a specific entry), even if you use the
-C<entry_model> method.
-
-If RDF::RDFa::Parser 1.09_04 or above is installed, then
-$opts{'atomowl'} will automatically pull in DataRSS data
-too.
-
-=cut
-
 sub model
 {
 	my ($self, %opts)  = @_;
@@ -531,15 +324,6 @@ sub entry_model
 	return $model;
 }
 
-=item C<< $feed->add_to_model($model, %opts) >>,
-C<< $feed->entry_add_to_model($entry, $model, %opts) >>.
-
-Adds data to an existing RDF::Trine::Model. Otherwise, the same as C<model>.
-
-=back
-
-=cut
-
 sub add_to_model
 {
 	my ($self, $model, %opts) = @_;
@@ -578,7 +362,6 @@ sub entry_add_to_model
 		my $iter = $context->{'HMF'}->model->as_stream;
 		while (my $st = $iter->next)
 		{
-			use RDF::TrineShortcuts;
 			$model->add_statement(
 				RDF::Trine::Statement->new(($st->nodes)[0..2]),
 				RDF::Trine::Node::Resource->new($entry),
@@ -600,17 +383,242 @@ sub entry_add_to_model
 
 1;
 
+__END__
+
+=head1 NAME
+
+XML::Atom::Microformats - parse microformats in Atom content
+
+=head1 SYNOPSIS
+
+ use XML::Atom::Microformats;
+ 
+ my $feed = HTML::Microformats
+             ->new_feed($xml, $base_uri)
+             ->assume_profile(qw(hCard hCalendar));
+ print $feed->json(pretty => 1);
+ 
+ use RDF::TrineShortcuts qw(rdf_query);
+ my $results = rdf_query($sparql, $feed->model);
+ 
+=head1 DESCRIPTION
+
+The XML::Atom::Microformats module brings the functionality of
+L<HTML::Microformats> to Atom 1.0 Syndication feeds. It finds
+microformats embedded in the E<lt>contentE<gt> elements
+(note: not E<lt>summaryE<gt>) of Atom entries.
+
+The general pattern of usage is to create an XML::Atom::Microformats
+object (which corresponds to an Atom 1.0 feed) using the
+C<new_feed> method; tell it which types of Microformat you expect
+to find there; then ask for the data, as a Perl hashref,
+a JSON string, or an RDF::Trine model.
+
+=head2 Constructor
+
+=over 4
+
+=item C<< XML::Atom::Microformats->new_feed($xml, $base_url) >>
+
+Constructs a feed object.
+
+$xml is the Atom source (string) or an XML::LibXML::Document.
+
+$base_url is the feed URL, important for resolving relative URL references.
+
+=back
+
+=head2 Profile Management Methods
+
+HTML::Microformats uses HTML profiles (i.e. the profile attribute on the
+HTML <head> element) to detect which Microformats are used on a page. Any
+microformats which do not have a profile URI declared will not be parsed.
+
+XML::Atom::Microformats uses a similar mechanism. Because Atom does not
+have a E<lt>headE<gt> element, Atom E<lt>linkE<gt> is used instead:
+
+  <link rel="profile" href="http://ufs.cc/x/hcalendar" />
+
+These links can be used on a per-entry basis, or for the whole feed.
+
+Because many feeds fail to properly declare which profiles they use, there
+are various profile management methods to tell XML::Atom::Microformats to
+assume the presence of particular profile URIs, even if they're actually
+missing.
+
+=over 4
+
+=item C<< add_profile(@profiles) >>
+
+Using C<add_profile> you can add one or more profile URIs, and they are
+treated as if they were found on the document.
+
+For example:
+
+ $feed->add_profile('http://microformats.org/profile/rel-tag')
+
+This is useful for adding profile URIs declared outside the document itself
+(e.g. in HTTP headers).
+
+=item C<< entry_add_profile($entryid, @profiles) >>
+
+C<entry_add_profile> is a variant to allow you to add a profile which applies
+only to one specific entry within the feed, if you know that entry's ID.
+
+=item C<< assume_profile(@microformats) >>
+
+For example:
+
+ $feed->assume_profile(qw(hCard adr geo))
+
+This method acts similarly to C<add_profile> but allows you to use
+names of microformats rather than URIs. Microformat names are case
+sensitive, and must match HTML::Microformats::Format::Foo module names.
+
+=item C<< entry_assume_profile($entryid, @profiles) >>
+
+C<entry_assume_profile> is a variant to allow you to add a profile which applies
+only to one specific entry within the feed, if you know that entry's ID.
+
+=item C<< assume_all_profiles >>
+
+This method is equivalent to calling C<assume_profile> for
+all known microformats.
+
+=item C<< entry_assume_all_profiles($entryid) >>
+
+This method is equivalent to calling C<entry_assume_profile> for
+all known microformats.
+
+=back
+
+=head2 Parsing Methods
+
+You can probably skip this section. The C<data>, C<json> and
+C<model> methods will automatically do this for you.
+
+=over 4
+
+=item C<< parse_microformats >>
+
+Scans through the feed, finding microformat objects.
+
+On subsequent calls, does nothing (as everything is already parsed).
+
+=item C<< clear_microformats >>
+
+Forgets information gleaned by C<parse_microformats> and thus allows
+C<parse_microformats> to be run again. This is useful if you've
+added some profiles between runs of C<parse_microformats>.
+
+=back
+
+=head2 Data Retrieval Methods
+
+These methods allow you to retrieve the feed's data, and do things
+with it.
+
+=over 4
+
+=item C<< objects($format) >>
+
+$format is, for example, 'hCard', 'adr' or 'RelTag'.
+
+Returns a list of objects of that type. (If called in scalar context,
+returns an arrayref.)
+
+Each object is, for example, an HTML::Microformat::hCard object, or an
+HTML::Microformat::RelTag object, etc. See the relevent documentation
+for details.
+
+=item C<< entry_objects($entryid, $format) >>
+
+C<entry_objects> is a variant to allow you to fetch data for
+one specific entry within the feed, if you know that entry's ID.
+
+=item C<< all_objects >>
+
+Returns a hashref of data. Each hashref key is the name of a microformat
+(e.g. 'hCard', 'RelTag', etc), and the values are arrayrefs of objects.
+
+Each object is, for example, an HTML::Microformat::hCard object, or an
+HTML::Microformat::RelTag object, etc. See the relevent documentation
+for details.
+
+=item C<< entry_all_objects($entryid) >>
+
+C<entry_all_objects> is a variant to allow you to fetch data for
+one specific entry within the feed, if you know that entry's ID.
+
+=item C<< json(%opts) >>
+
+Returns data roughly equivalent to the C<all_objects> method, but as a JSON
+string.
+
+%opts is a hash of options, suitable for passing to the L<JSON>
+module's to_json function. The 'convert_blessed' and 'utf8' options are
+enabled by default, but can be disabled by explicitly setting them to 0, e.g.
+
+  print $feed->json( pretty=>1, canonical=>1, utf8=>0 );
+
+=item C<< entry_json($entryid, %opts) >>
+
+C<entry_json> is a variant to allow you to fetch data for
+one specific entry within the feed, if you know that entry's ID.
+
+=item C<< model(%opts) >>
+
+Returns data as an RDF::Trine::Model, suitable for serialising as
+RDF or running SPARQL queries. Quads are used (rather than
+triples) which allows you to trace statements to the entries from
+which they came.
+
+$opts{'atomowl'} is a boolean indicating whether or not to
+include data from XML::Atom::OWL in the returned model.
+If enabled, this always includes AtomOWL data for the whole
+feed (not just for a specific entry), even if you use the
+C<entry_model> method.
+
+If RDF::RDFa::Parser 1.096 or above is installed, then
+$opts{'atomowl'} will automatically pull in DataRSS data
+too.
+
+=item C<< entry_model($entryid, %opts) >>
+
+C<entry_model> is a variant to allow you to fetch data for
+one specific entry within the feed, if you know that entry's ID.
+
+=item C<< add_to_model($model, %opts) >>
+
+Adds data to an existing RDF::Trine::Model. Otherwise, the same as C<model>.
+
+=item C<< entry_add_to_model($entry, $model, %opts) >>
+
+Adds data to an existing RDF::Trine::Model. Otherwise, the same as C<entry_model>.
+
+=begin private
+
+=item C<< TO_JSON >>
+
+Provided for the benefit of L<JSON>'s convert_blessed feature.
+
+=end private
+
+=back
+
 =head1 BUGS
 
 Please report any bugs to L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
-L<XML::Atom::OWL>,
 L<HTML::Microformats>,
+L<XML::Atom::OWL>,
+L<XML::Atom::FromOWL>,
 L<RDF::RDFa::Parser>.
 
-L<http://microformats.org/>, L<http://www.perlrdf.org/>.
+L<http://microformats.org/>,
+L<http://www.perlrdf.org/>.
 
 =head1 AUTHOR
 
@@ -618,10 +626,14 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2010 Toby Inkster
+Copyright 2010-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
-=cut
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
